@@ -6,13 +6,11 @@ from pykt.datasets.data_loader import KTDataset
 from pykt.datasets.dkt_forget_dataloader import DktForgetDataset
 
 def set_seed(seed):
-    '''
-    try:
-        import tensorflow as tf
-        tf.random.set_random_seed(seed)
-    except Exception as e:
-        print("Set seed failed,details are ", e)
-    '''
+    """Set the global random seed.
+    
+    Args:
+        seed (int): random seed
+    """
     try:
         import torch
         torch.manual_seed(seed)
@@ -34,9 +32,20 @@ def set_seed(seed):
 
 import datetime
 def get_now_time():
+    """Return the time string, the format is %Y-%m-%d %H:%M:%S
+
+    Returns:
+        str: now time
+    """
     now = datetime.datetime.now()
     dt_string = now.strftime("%Y-%m-%d %H:%M:%S")
     return dt_string
 
 def debug_print(text,fuc_name=""):
+    """Printing text with function name.
+
+    Args:
+        text (str): the text will print
+        fuc_name (str, optional): _description_. Defaults to "".
+    """
     print(f"{get_now_time()} - {fuc_name} - said: {text}")
\ No newline at end of file
